@@ -1,40 +1,29 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 1999,2000 Kurt Granroth <granroth@kde.org>
-   Copyright (C) 2001,2002 Ellis Whitehead <ellis@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999, 2000 Kurt Granroth <granroth@kde.org>
+    SPDX-FileCopyrightText: 2001, 2002 Ellis Whitehead <ellis@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 #ifndef KSTANDARDACTION_H
 #define KSTANDARDACTION_H
 
 #include <QAction>
 #include <QList>
+#include <QStringList>
 
-#include <kconfigwidgets_export.h>
 #include <KStandardShortcut>
-#include <krecentfilesaction.h>
 #include <KToggleAction>
+#include <kconfigwidgets_export.h>
+#include <khamburgermenu.h>
+#include <krecentfilesaction.h>
 #include <ktogglefullscreenaction.h>
 
 #include <type_traits>
 
 class QObject;
-class QStringList;
 class QWidget;
 class QAction;
-class KDualAction;
 class KToggleAction;
 class KToggleFullScreenAction;
 
@@ -55,20 +44,20 @@ class KToggleFullScreenAction;
  * <b>Simple Example:</b>\n
  *
  * In general, using standard actions should be a drop in replacement
- * for regular actions.  For example, if you previously had:
+ * for regular actions. For example, if you previously had:
+ * @code
+ * QAction *newAct = new QAction(i18n("&New"),
+ *                               QIcon::fromTheme("document-new"),
+ *                               KStandardShortcut::shortcut(KStandardShortcut::New),
+ *                               this,
+ *                               &ClassFoo::fileNew,
+ *                               actionCollection());
+ * @endcode
  *
- * \code
- * QAction *newAct = new QAction(i18n("&New"), QIcon::fromTheme("document-new"),
- *                               KStandardShortcut::shortcut(KStandardShortcut::New), this,
- *                               SLOT(fileNew()), actionCollection());
- * \endcode
- *
- * You could drop that and replace it with:
- *
- * \code
- * QAction *newAct = KStandardAction::openNew(this, SLOT(fileNew()),
- *                                       actionCollection());
- * \endcode
+ * You can replace it with:
+ * @code
+ * QAction *newAct = KStandardAction::openNew(this, &ClassFoo::fileNew, actionCollection());
+ * @endcode
  *
  * <b>Non-standard Usages</b>\n
  *
@@ -186,16 +175,18 @@ enum StandardAction {
     ShowToolbar, ///< Show/Hide the toolbar.
     ShowStatusbar, ///< Show/Hide the statusbar.
 #if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 38)
-    SaveOptions, ///< @deprecated since 5.38
+    SaveOptions ///< @deprecated Since 5.38, no known users.
+        KCONFIGWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 38, "No known users"),
 #elif KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(5, 38)
     SaveOptions_DEPRECATED_DO_NOT_USE,
 #endif
     KeyBindings, ///< Display the configure key bindings dialog.
     Preferences, ///< Display the preferences/options dialog.
     ConfigureToolbars, ///< Display the toolbar configuration dialog.
-    // Help Menu
+// Help Menu
 #if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 38)
-    Help, ///< @deprecated since 5.38. Use HelpContents instead.
+    Help ///< @deprecated Since 5.38, use HelpContents instead.
+        KCONFIGWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 38, "Use HelpContents instead"),
 #elif KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(5, 38)
     Help_DEPRECATED_DO_NOT_USE,
 #endif
@@ -210,7 +201,8 @@ enum StandardAction {
     FullScreen, ///< Switch to/from full screen mode.
     Clear, ///< Clear the content of the focus widget.
 #if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 39)
-    PasteText, ///< @deprecated since 5.39. Use Paste instead.
+    PasteText ///< @deprecated Since 5.39, use Paste instead.
+        KCONFIGWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 39, "Use Paste instead"),
 #elif KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(5, 39)
     PasteText_DEPRECATED_DO_NOT_USE,
 #endif
@@ -218,7 +210,8 @@ enum StandardAction {
     DeleteFile, ///< Permanently deletes files or folders. @since 5.25
     RenameFile, ///< Renames files or folders. @since 5.25
     MoveToTrash, ///< Moves files or folders to the trash. @since 5.25
-    Donate ///< Open donation page on kde.org. @since 5.26
+    Donate, ///< Open donation page on kde.org. @since 5.26
+    HamburgerMenu ///< Opens a menu that substitutes the menubar. @since 5.81
 };
 
 /**
@@ -237,8 +230,7 @@ enum StandardAction {
  * @param parent The QObject that should own the created QAction, or @c nullptr if no parent will
  *               own the QAction returned (ensure you delete it manually in this case).
  */
-KCONFIGWIDGETS_EXPORT QAction *create(StandardAction id, const QObject *recvr, const char *slot,
-                                      QObject *parent);
+KCONFIGWIDGETS_EXPORT QAction *create(StandardAction id, const QObject *recvr, const char *slot, QObject *parent);
 
 /**
  * @internal
@@ -253,10 +245,11 @@ KCONFIGWIDGETS_EXPORT QAction *_k_createInternal(StandardAction id, QObject *par
  * @since 5.23
  */
 #ifdef K_DOXYGEN
-inline QAction *create(StandardAction id, const QObject *recvr, Func slot, QObject* parent)
+inline QAction *create(StandardAction id, const QObject *recvr, Func slot, QObject *parent)
 #else
 template<class Receiver, class Func>
-inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, QAction>::type *create(StandardAction id, const Receiver *recvr, Func slot, QObject *parent)
+inline typename std::enable_if<!std::is_convertible<Func, const char *>::value, QAction>::type *
+create(StandardAction id, const Receiver *recvr, Func slot, QObject *parent)
 #endif
 {
     QAction *action = _k_createInternal(id, parent);
@@ -268,7 +261,6 @@ inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, Q
     return action;
 }
 
-
 /**
  * This will return the internal name of a given standard action.
  */
@@ -305,7 +297,7 @@ KCONFIGWIDGETS_EXPORT QList<StandardAction> actionIds();
  */
 KCONFIGWIDGETS_EXPORT KStandardShortcut::StandardShortcut shortcutForActionId(StandardAction id);
 
-
+// clang-format off
 // we have to disable the templated function for const char* as Func, since it is ambiguous otherwise
 // TODO: KF6: unify const char* version and new style by removing std::enable_if
 #ifdef K_DOXYGEN
@@ -317,6 +309,7 @@ KCONFIGWIDGETS_EXPORT KStandardShortcut::StandardShortcut shortcutForActionId(St
     inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, QAction>::type *name(const Receiver *recvr, Func slot, QObject *parent) \
     { return create(enumValue, recvr, slot, parent); }
 #endif
+// clang-format on
 
 /**
  * Create a new document or window.
@@ -359,11 +352,12 @@ KCONFIGWIDGETS_EXPORT KRecentFilesAction *openRecent(const QObject *recvr, const
 inline KRecentFilesAction *openRecent(const QObject *recvr, Func slot, QObject *parent)
 #else
 template<class Receiver, class Func>
-inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, KRecentFilesAction>::type *openRecent(const Receiver *recvr, Func slot, QObject *parent)
+inline typename std::enable_if<!std::is_convertible<Func, const char *>::value, KRecentFilesAction>::type *
+openRecent(const Receiver *recvr, Func slot, QObject *parent)
 #endif
 {
-    QAction* action = _k_createInternal(OpenRecent, parent);
-    KRecentFilesAction* recentAction = qobject_cast<KRecentFilesAction*>(action);
+    QAction *action = _k_createInternal(OpenRecent, parent);
+    KRecentFilesAction *recentAction = qobject_cast<KRecentFilesAction *>(action);
     Q_ASSERT(recentAction);
     QObject::connect(recentAction, &KRecentFilesAction::urlSelected, recvr, slot);
     return recentAction;
@@ -571,8 +565,9 @@ KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(paste, Paste)
 /**
  * @deprecated since 5.39. Use paste() instead.
  */
+KCONFIGWIDGETS_EXPORT
 KCONFIGWIDGETS_DEPRECATED_VERSION(5, 39, "Use KStandardAction::paste(const QObject *, const char *, QObject *)")
-KCONFIGWIDGETS_EXPORT QAction *pasteText(const QObject *recvr, const char *slot, QObject *parent);
+QAction *pasteText(const QObject *recvr, const char *slot, QObject *parent);
 #endif
 
 #if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 39)
@@ -581,12 +576,14 @@ KCONFIGWIDGETS_EXPORT QAction *pasteText(const QObject *recvr, const char *slot,
  * @deprecated since 5.39. Use paste() instead.
  */
 #ifdef K_DOXYGEN
-    inline QAction *pasteText(const QObject *recvr, Func slot, QObject *parent);
+inline QAction *pasteText(const QObject *recvr, Func slot, QObject *parent);
 #else
 template<class Receiver, class Func>
 KCONFIGWIDGETS_DEPRECATED_VERSION(5, 39, "Use KStandardAction::paste(const QObject *, Func, QObject *)")
-inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, QAction>::type *pasteText(const Receiver *recvr, Func slot, QObject *parent)
-{ return create(PasteText, recvr, slot, parent); }
+inline typename std::enable_if<!std::is_convertible<Func, const char *>::value, QAction>::type *pasteText(const Receiver *recvr, Func slot, QObject *parent)
+{
+    return create(PasteText, recvr, slot, parent);
+}
 #endif // K_DOXYGEN
 #endif // KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE
 
@@ -945,10 +942,11 @@ KCONFIGWIDGETS_EXPORT KToggleAction *showMenubar(const QObject *recvr, const cha
 inline KToggleAction *showMenubar(const QObject *recvr, Func slot, QObject *parent)
 #else
 template<class Receiver, class Func>
-inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, KToggleAction>::type *showMenubar(const Receiver *recvr, Func slot, QObject *parent)
+inline typename std::enable_if<!std::is_convertible<Func, const char *>::value, KToggleAction>::type *
+showMenubar(const Receiver *recvr, Func slot, QObject *parent)
 #endif
 {
-    QAction* ret = create(ShowMenubar, recvr, slot, parent);
+    QAction *ret = create(ShowMenubar, recvr, slot, parent);
     Q_ASSERT(qobject_cast<KToggleAction *>(ret));
     return static_cast<KToggleAction *>(ret);
 }
@@ -966,10 +964,11 @@ KCONFIGWIDGETS_EXPORT KToggleAction *showStatusbar(const QObject *recvr, const c
 inline KToggleAction *showStatusbar(const QObject *recvr, Func slot, QObject *parent)
 #else
 template<class Receiver, class Func>
-inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, KToggleAction>::type *showStatusbar(const Receiver *recvr, Func slot, QObject *parent)
+inline typename std::enable_if<!std::is_convertible<Func, const char *>::value, KToggleAction>::type *
+showStatusbar(const Receiver *recvr, Func slot, QObject *parent)
 #endif
 {
-    QAction* ret = create(ShowStatusbar, recvr, slot, parent);
+    QAction *ret = create(ShowStatusbar, recvr, slot, parent);
     Q_ASSERT(qobject_cast<KToggleAction *>(ret));
     return static_cast<KToggleAction *>(ret);
 }
@@ -987,10 +986,11 @@ KCONFIGWIDGETS_EXPORT KToggleFullScreenAction *fullScreen(const QObject *recvr,
 inline KToggleFullScreenAction *fullScreen(const QObject *recvr, Func slot, QWidget *window, QObject *parent)
 #else
 template<class Receiver, class Func>
-inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, KToggleFullScreenAction>::type *fullScreen(const Receiver *recvr, Func slot, QWidget *window, QObject *parent)
+inline typename std::enable_if<!std::is_convertible<Func, const char *>::value, KToggleFullScreenAction>::type *
+fullScreen(const Receiver *recvr, Func slot, QWidget *window, QObject *parent)
 #endif
 {
-    QAction* a = create(FullScreen, recvr, slot, parent);
+    QAction *a = create(FullScreen, recvr, slot, parent);
     Q_ASSERT(qobject_cast<KToggleFullScreenAction *>(a));
     KToggleFullScreenAction *ret = static_cast<KToggleFullScreenAction *>(a);
     ret->setWindow(window);
@@ -1002,8 +1002,9 @@ inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, K
  * Display the save options dialog.
  * @deprecated since 5.38
  */
+KCONFIGWIDGETS_EXPORT
 KCONFIGWIDGETS_DEPRECATED_VERSION(5, 38, "No usage known, candidate for removal on next ABI break")
-KCONFIGWIDGETS_EXPORT QAction *saveOptions(const QObject *recvr, const char *slot, QObject *parent);
+QAction *saveOptions(const QObject *recvr, const char *slot, QObject *parent);
 #endif
 
 #if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 38)
@@ -1013,20 +1014,29 @@ KCONFIGWIDGETS_EXPORT QAction *saveOptions(const QObject *recvr, const char *slo
  * @deprecated since 5.38
  */
 #ifdef K_DOXYGEN
-    inline QAction *saveOptions(const QObject *recvr, Func slot, QObject *parent);
+inline QAction *saveOptions(const QObject *recvr, Func slot, QObject *parent);
 #else
 template<class Receiver, class Func>
-KCONFIGWIDGETS_DEPRECATED_VERSION(5, 38, "No usage known, candidate for removal on next ABI break")
-KCONFIGWIDGETS_EXPORT inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, QAction>::type *saveOptions(const Receiver *recvr, Func slot, QObject *parent)
-{ return create(SaveOptions, recvr, slot, parent); }
+KCONFIGWIDGETS_EXPORT KCONFIGWIDGETS_DEPRECATED_VERSION(5, 38, "No usage known, candidate for removal on next ABI break") inline
+    typename std::enable_if<!std::is_convertible<Func, const char *>::value, QAction>::type *saveOptions(const Receiver *recvr, Func slot, QObject *parent)
+{
+    return create(SaveOptions, recvr, slot, parent);
+}
 #endif // K_DOXYGEN
 #endif // KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE
 
 /**
- * Display the configure key bindings dialog.
+ * Display the configure keyboard shortcuts dialog.
+ *
+ * Note that you might be able to use the pre-built KXMLGUIFactory's function:
+ * @code
+ * // For versions older than 5.84:
+ * KStandardAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), actionCollection());
+ * // Starting from 5.84 you can use this (the KXMLGUIFactory::configureShortcuts() method is
+ * // deprecated in 5.84):
+ * KStandardAction::keyBindings(guiFactory(), &KXMLGUIFactory::showConfigureShortcutsDialog, actionCollection());
+ * @endcode
  *
- *  Note that you might be able to use the pre-built KXMLGUIFactory's function:
- *  KStandardAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), actionCollection());
  */
 KCONFIGWIDGETS_EXPORT QAction *keyBindings(const QObject *recvr, const char *slot, QObject *parent);
 
@@ -1086,8 +1096,9 @@ KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(switchApplicationLanguage, SwitchApplicat
 /**
  * @deprecated since 5.38 Use helpContents() instead.
  */
+KCONFIGWIDGETS_EXPORT
 KCONFIGWIDGETS_DEPRECATED_VERSION(5, 23, "Use KStandardAction::helpContents(const QObject *, const char *, QObject *)")
-KCONFIGWIDGETS_EXPORT QAction *help(const QObject *recvr, const char *slot, QObject *parent);
+QAction *help(const QObject *recvr, const char *slot, QObject *parent);
 #endif
 
 #if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 38)
@@ -1096,12 +1107,14 @@ KCONFIGWIDGETS_EXPORT QAction *help(const QObject *recvr, const char *slot, QObj
  * @deprecated since 5.38 Use helpContents() instead.
  */
 #ifdef K_DOXYGEN
-    inline QAction *help(const QObject *recvr, Func slot, QObject *parent);
+inline QAction *help(const QObject *recvr, Func slot, QObject *parent);
 #else
 template<class Receiver, class Func>
-KCONFIGWIDGETS_DEPRECATED_VERSION(5, 38, "Use KStandardAction::helpContents(const QObject *, Func, QObject *)")
-KCONFIGWIDGETS_EXPORT inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, QAction>::type *help(const Receiver *recvr, Func slot, QObject *parent)
-{ return create(Help, recvr, slot, parent); }
+KCONFIGWIDGETS_EXPORT KCONFIGWIDGETS_DEPRECATED_VERSION(5, 38, "Use KStandardAction::helpContents(const QObject *, Func, QObject *)") inline
+    typename std::enable_if<!std::is_convertible<Func, const char *>::value, QAction>::type *help(const Receiver *recvr, Func slot, QObject *parent)
+{
+    return create(Help, recvr, slot, parent);
+}
 #endif // K_DOXYGEN
 #endif // KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE
 
@@ -1219,6 +1232,18 @@ KCONFIGWIDGETS_EXPORT QAction *donate(const QObject *recvr, const char *slot, QO
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(donate, Donate)
 
+/**
+ * Opens a menu that substitutes the menubar.
+ * @since 5.81
+ */
+KCONFIGWIDGETS_EXPORT KHamburgerMenu *hamburgerMenu(const QObject *recvr, const char *slot, QObject *parent);
+
+/**
+ * Opens a menu that substitutes the menubar.
+ * @since 5.81
+ */
+KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(hamburgerMenu, HamburgerMenu)
+
 }
 
 #endif // KSTDACTION_H
